Name: liquidctl
%global pypi_name %{name}

Summary: Tool for controlling liquid coolers, case fans and RGB LED strips
License: GPL-3.0-or-later

Version: 1.13.0
Release:    1%{?dist}

URL: https://github.com/jonasmalacofilho/liquidctl
Source0: %{pypi_source}

BuildArch: noarch
BuildRequires: python3-devel
BuildRequires: systemd-rpm-macros

ExcludeArch: s390 s390x

Requires: python3-%{name} = %{version}-%{release}
Suggests: %{name}-udev = %{version}-%{release}


%description
liquidctl is a tool for controlling various settings of PC internals, such as:
- liquid cooler pump speed
- case fan speed
- RGB LED strip colors

For a full list of supported devices, visit:
https://github.com/liquidctl/liquidctl#supported-devices


%package -n python3-%{name}
Summary: Module for controlling liquid coolers, case fans and RGB LED devices

%description -n python3-%{name}
A python module providing classes for communicating with various cooling devices
and RGB LED solutions.

Currently supported devices are: %{supported_devices}

Devices with experimental support: %{supported_devices_experimental}


%package udev
Summary: Unprivileged device access rules for %{name}
Requires: %{name} = %{version}-%{release}

%description udev
This package contains udev rules which allow %{name} to access relevant devices
when ran by an unprivileged user.


%package doc
Summary: Documentation for %{name}

%description doc
This package contains documentation for %{name}, including
device-specific guides and developer docs.


%prep
%setup -q -n %{name}-%{version}

%generate_buildrequires
%pyproject_buildrequires -t


%build
export DIST_NAME=$(source /etc/os-release && echo "${NAME} ${VERSION_ID}")
export DIST_PACKAGE="%{name}-%{version}-%{release}.%{_build_arch}"
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files %{name}

install -Dp -m 644 \
	liquidctl.8 \
	%{buildroot}%{_mandir}/man8/%{name}.8

install -Dp -m 644 \
	extra/completions/liquidctl.bash \
	%{buildroot}%{_datadir}/bash-completion/completions/%{name}

install -Dp -m 644 \
	extra/linux/71-%{name}.rules \
	%{buildroot}%{_udevrulesdir}/71-%{name}.rules

install -Dp -m 644 -t %{buildroot}%{_pkgdocdir} \
	CHANGELOG.md README.md
cp -a docs/ %{buildroot}%{_pkgdocdir}/


%check
exit 0
mkdir ./test-run-dir
XDG_RUNTIME_DIR=$(pwd)/test-run-dir pytest-3


%files
%doc %{_pkgdocdir}/*.md
%{_bindir}/%{name}
%{_mandir}/man8/%{name}.*
%{_datadir}/bash-completion/completions/%{name}

%files -n python3-%{name} -f %{pyproject_files}
%license LICENSE.txt

%files udev
%{_udevrulesdir}/71-%{name}.rules

%files doc
%dir %{_pkgdocdir}
%{_pkgdocdir}/docs


%changelog
* Mon Jul 01 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.13.0-1
- initial build
